# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Project.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Definitions_pb2 as Definitions__pb2
import Case_pb2 as Case__pb2
import PdmObject_pb2 as PdmObject__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Project.proto',
  package='rips',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rProject.proto\x12\x04rips\x1a\x11\x44\x65\x66initions.proto\x1a\nCase.proto\x1a\x0fPdmObject.proto2\xc8\x02\n\x07Project\x12\x32\n\x0eGetCurrentCase\x12\x0b.rips.Empty\x1a\x11.rips.CaseRequest\"\x00\x12\x36\n\x10GetSelectedCases\x12\x0b.rips.Empty\x1a\x13.rips.CaseInfoArray\"\x00\x12\x33\n\x10GetAllCaseGroups\x12\x0b.rips.Empty\x1a\x10.rips.CaseGroups\"\x00\x12\x31\n\x0bGetAllCases\x12\x0b.rips.Empty\x1a\x13.rips.CaseInfoArray\"\x00\x12\x39\n\x0fGetCasesInGroup\x12\x0f.rips.CaseGroup\x1a\x13.rips.CaseInfoArray\"\x00\x12.\n\x0cGetPdmObject\x12\x0b.rips.Empty\x1a\x0f.rips.PdmObject\"\x00\x62\x06proto3'
  ,
  dependencies=[Definitions__pb2.DESCRIPTOR,Case__pb2.DESCRIPTOR,PdmObject__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_PROJECT = _descriptor.ServiceDescriptor(
  name='Project',
  full_name='rips.Project',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=72,
  serialized_end=400,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCurrentCase',
    full_name='rips.Project.GetCurrentCase',
    index=0,
    containing_service=None,
    input_type=Definitions__pb2._EMPTY,
    output_type=Case__pb2._CASEREQUEST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSelectedCases',
    full_name='rips.Project.GetSelectedCases',
    index=1,
    containing_service=None,
    input_type=Definitions__pb2._EMPTY,
    output_type=Case__pb2._CASEINFOARRAY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllCaseGroups',
    full_name='rips.Project.GetAllCaseGroups',
    index=2,
    containing_service=None,
    input_type=Definitions__pb2._EMPTY,
    output_type=Case__pb2._CASEGROUPS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllCases',
    full_name='rips.Project.GetAllCases',
    index=3,
    containing_service=None,
    input_type=Definitions__pb2._EMPTY,
    output_type=Case__pb2._CASEINFOARRAY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCasesInGroup',
    full_name='rips.Project.GetCasesInGroup',
    index=4,
    containing_service=None,
    input_type=Case__pb2._CASEGROUP,
    output_type=Case__pb2._CASEINFOARRAY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPdmObject',
    full_name='rips.Project.GetPdmObject',
    index=5,
    containing_service=None,
    input_type=Definitions__pb2._EMPTY,
    output_type=PdmObject__pb2._PDMOBJECT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROJECT)

DESCRIPTOR.services_by_name['Project'] = _PROJECT

# @@protoc_insertion_point(module_scope)



from rips.generated.generated_classes import (
    ModeledWellPath,
    StimPlanModel,
    WellPathGeometry,
    WellPathTarget,
)
import sys
import os

sys.path.insert(1, os.path.join(sys.path[0], "../../"))
import rips


def test_well_path_target(rips_instance, initialize_test):
    well_path_coll = rips_instance.project.descendants(rips.WellPathCollection)[0]

    my_well_path = well_path_coll.add_new_object(rips.ModeledWellPath)
    my_well_path.name = "test"
    my_well_path.update()

    geometry = my_well_path.well_path_geometry()
    geometry.add_new_object(rips.WellPathTarget)
    geometry.add_new_object(rips.WellPathTarget)
    geometry.add_new_object(rips.WellPathTarget)
    assert len(geometry.well_path_targets()) == 3

    assert len(well_path_coll.well_paths()) == 1
    my_well_path_duplicate = well_path_coll.well_paths()[0]
    assert my_well_path_duplicate.name == "test"
    geometry_duplicate = my_well_path_duplicate.well_path_geometry()
    assert len(geometry_duplicate.well_path_targets()) == 3

    # Not allowed to add object of unrelated type
    invalid_object = geometry.add_new_object(rips.WellPath)
    assert invalid_object is None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Definitions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='Definitions.proto',
  package='rips',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x44\x65\x66initions.proto\x12\x04rips\"\x07\n\x05\x45mpty\"9\n\x19\x43lientToServerStreamReply\x12\x1c\n\x14\x61\x63\x63\x65pted_value_count\x18\x01 \x01(\x03\"(\n\x05Vec3i\x12\t\n\x01i\x18\x01 \x01(\x05\x12\t\n\x01j\x18\x02 \x01(\x05\x12\t\n\x01k\x18\x03 \x01(\x05\"(\n\x05Vec3d\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"+\n\x0b\x43\x65llCenters\x12\x1c\n\x07\x63\x65nters\x18\x01 \x03(\x0b\x32\x0b.rips.Vec3d\"\xd5\x01\n\x0b\x43\x65llCorners\x12\x17\n\x02\x63\x30\x18\x01 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x31\x18\x02 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x32\x18\x03 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x33\x18\x04 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x34\x18\x05 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x35\x18\x06 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x36\x18\x07 \x01(\x0b\x32\x0b.rips.Vec3d\x12\x17\n\x02\x63\x37\x18\x08 \x01(\x0b\x32\x0b.rips.Vec3d\"4\n\x10\x43\x65llCornersArray\x12 \n\x05\x63\x65lls\x18\x01 \x03(\x0b\x32\x11.rips.CellCornersb\x06proto3'
)




_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='rips.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=34,
)


_CLIENTTOSERVERSTREAMREPLY = _descriptor.Descriptor(
  name='ClientToServerStreamReply',
  full_name='rips.ClientToServerStreamReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accepted_value_count', full_name='rips.ClientToServerStreamReply.accepted_value_count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=93,
)


_VEC3I = _descriptor.Descriptor(
  name='Vec3i',
  full_name='rips.Vec3i',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='i', full_name='rips.Vec3i.i', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='j', full_name='rips.Vec3i.j', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k', full_name='rips.Vec3i.k', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=135,
)


_VEC3D = _descriptor.Descriptor(
  name='Vec3d',
  full_name='rips.Vec3d',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='rips.Vec3d.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='rips.Vec3d.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='rips.Vec3d.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=177,
)


_CELLCENTERS = _descriptor.Descriptor(
  name='CellCenters',
  full_name='rips.CellCenters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='centers', full_name='rips.CellCenters.centers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=222,
)


_CELLCORNERS = _descriptor.Descriptor(
  name='CellCorners',
  full_name='rips.CellCorners',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='c0', full_name='rips.CellCorners.c0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c1', full_name='rips.CellCorners.c1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c2', full_name='rips.CellCorners.c2', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c3', full_name='rips.CellCorners.c3', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c4', full_name='rips.CellCorners.c4', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c5', full_name='rips.CellCorners.c5', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c6', full_name='rips.CellCorners.c6', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c7', full_name='rips.CellCorners.c7', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=438,
)


_CELLCORNERSARRAY = _descriptor.Descriptor(
  name='CellCornersArray',
  full_name='rips.CellCornersArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cells', full_name='rips.CellCornersArray.cells', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=492,
)

_CELLCENTERS.fields_by_name['centers'].message_type = _VEC3D
_CELLCORNERS.fields_by_name['c0'].message_type = _VEC3D
_CELLCORNERS.fields_by_name['c1'].message_type = _VEC3D
_CELLCORNERS.fields_by_name['c2'].message_type = _VEC3D
_CELLCORNERS.fields_by_name['c3'].message_type = _VEC3D
_CELLCORNERS.fields_by_name['c4'].message_type = _VEC3D
_CELLCORNERS.fields_by_name['c5'].message_type = _VEC3D
_CELLCORNERS.fields_by_name['c6'].message_type = _VEC3D
_CELLCORNERS.fields_by_name['c7'].message_type = _VEC3D
_CELLCORNERSARRAY.fields_by_name['cells'].message_type = _CELLCORNERS
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['ClientToServerStreamReply'] = _CLIENTTOSERVERSTREAMREPLY
DESCRIPTOR.message_types_by_name['Vec3i'] = _VEC3I
DESCRIPTOR.message_types_by_name['Vec3d'] = _VEC3D
DESCRIPTOR.message_types_by_name['CellCenters'] = _CELLCENTERS
DESCRIPTOR.message_types_by_name['CellCorners'] = _CELLCORNERS
DESCRIPTOR.message_types_by_name['CellCornersArray'] = _CELLCORNERSARRAY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'Definitions_pb2'
  # @@protoc_insertion_point(class_scope:rips.Empty)
  })
_sym_db.RegisterMessage(Empty)

ClientToServerStreamReply = _reflection.GeneratedProtocolMessageType('ClientToServerStreamReply', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTTOSERVERSTREAMREPLY,
  '__module__' : 'Definitions_pb2'
  # @@protoc_insertion_point(class_scope:rips.ClientToServerStreamReply)
  })
_sym_db.RegisterMessage(ClientToServerStreamReply)

Vec3i = _reflection.GeneratedProtocolMessageType('Vec3i', (_message.Message,), {
  'DESCRIPTOR' : _VEC3I,
  '__module__' : 'Definitions_pb2'
  # @@protoc_insertion_point(class_scope:rips.Vec3i)
  })
_sym_db.RegisterMessage(Vec3i)

Vec3d = _reflection.GeneratedProtocolMessageType('Vec3d', (_message.Message,), {
  'DESCRIPTOR' : _VEC3D,
  '__module__' : 'Definitions_pb2'
  # @@protoc_insertion_point(class_scope:rips.Vec3d)
  })
_sym_db.RegisterMessage(Vec3d)

CellCenters = _reflection.GeneratedProtocolMessageType('CellCenters', (_message.Message,), {
  'DESCRIPTOR' : _CELLCENTERS,
  '__module__' : 'Definitions_pb2'
  # @@protoc_insertion_point(class_scope:rips.CellCenters)
  })
_sym_db.RegisterMessage(CellCenters)

CellCorners = _reflection.GeneratedProtocolMessageType('CellCorners', (_message.Message,), {
  'DESCRIPTOR' : _CELLCORNERS,
  '__module__' : 'Definitions_pb2'
  # @@protoc_insertion_point(class_scope:rips.CellCorners)
  })
_sym_db.RegisterMessage(CellCorners)

CellCornersArray = _reflection.GeneratedProtocolMessageType('CellCornersArray', (_message.Message,), {
  'DESCRIPTOR' : _CELLCORNERSARRAY,
  '__module__' : 'Definitions_pb2'
  # @@protoc_insertion_point(class_scope:rips.CellCornersArray)
  })
_sym_db.RegisterMessage(CellCornersArray)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PdmObject.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Definitions_pb2 as Definitions__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='PdmObject.proto',
  package='rips',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0fPdmObject.proto\x12\x04rips\x1a\x11\x44\x65\x66initions.proto\"T\n\x1aPdmDescendantObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x15\n\rchild_keyword\x18\x02 \x01(\t\"M\n\x15PdmChildObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x13\n\x0b\x63hild_field\x18\x02 \x01(\t\"j\n\x1b\x43reatePdmChildObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x13\n\x0b\x63hild_field\x18\x02 \x01(\t\x12\x15\n\rclass_keyword\x18\x03 \x01(\t\"Q\n\x16PdmParentObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x16\n\x0eparent_keyword\x18\x02 \x01(\t\"\xc0\x01\n\tPdmObject\x12\x15\n\rclass_keyword\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\x04\x12\x33\n\nparameters\x18\x03 \x03(\x0b\x32\x1f.rips.PdmObject.ParametersEntry\x12\x0f\n\x07visible\x18\x04 \x01(\x08\x12\x12\n\npersistent\x18\x05 \x01(\x08\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x0ePdmObjectArray\x12 \n\x07objects\x18\x01 \x03(\x0b\x32\x0f.rips.PdmObject\"I\n\x16PdmObjectGetterRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x0e\n\x06method\x18\x02 \x01(\t\"[\n\x16PdmObjectSetterRequest\x12-\n\x07request\x18\x01 \x01(\x0b\x32\x1c.rips.PdmObjectGetterRequest\x12\x12\n\ndata_count\x18\x02 \x01(\x05\"\xbf\x01\n\x14PdmObjectSetterChunk\x12\x33\n\x0bset_request\x18\x01 \x01(\x0b\x32\x1c.rips.PdmObjectSetterRequestH\x00\x12$\n\x07\x64oubles\x18\x02 \x01(\x0b\x32\x11.rips.DoubleArrayH\x00\x12\x1e\n\x04ints\x18\x03 \x01(\x0b\x32\x0e.rips.IntArrayH\x00\x12$\n\x07strings\x18\x04 \x01(\x0b\x32\x11.rips.StringArrayH\x00\x42\x06\n\x04\x64\x61ta\"\x1b\n\x0b\x44oubleArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"\x18\n\x08IntArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x05\"\x1b\n\x0bStringArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\"\x8a\x01\n\x14PdmObjectGetterReply\x12$\n\x07\x64oubles\x18\x01 \x01(\x0b\x32\x11.rips.DoubleArrayH\x00\x12\x1e\n\x04ints\x18\x02 \x01(\x0b\x32\x0e.rips.IntArrayH\x00\x12$\n\x07strings\x18\x03 \x01(\x0b\x32\x11.rips.StringArrayH\x00\x42\x06\n\x04\x64\x61ta\"j\n\x16PdmObjectMethodRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x1f\n\x06params\x18\x03 \x01(\x0b\x32\x0f.rips.PdmObject2\xf9\x04\n\x10PdmObjectService\x12S\n\x17GetDescendantPdmObjects\x12 .rips.PdmDescendantObjectRequest\x1a\x14.rips.PdmObjectArray\"\x00\x12I\n\x12GetChildPdmObjects\x12\x1b.rips.PdmChildObjectRequest\x1a\x14.rips.PdmObjectArray\"\x00\x12G\n\x14GetAncestorPdmObject\x12\x1c.rips.PdmParentObjectRequest\x1a\x0f.rips.PdmObject\"\x00\x12L\n\x14\x43reateChildPdmObject\x12!.rips.CreatePdmChildObjectRequest\x1a\x0f.rips.PdmObject\"\x00\x12\x39\n\x17UpdateExistingPdmObject\x12\x0f.rips.PdmObject\x1a\x0b.rips.Empty\"\x00\x12S\n\x13\x43\x61llPdmObjectGetter\x12\x1c.rips.PdmObjectGetterRequest\x1a\x1a.rips.PdmObjectGetterReply\"\x00\x30\x01\x12V\n\x13\x43\x61llPdmObjectSetter\x12\x1a.rips.PdmObjectSetterChunk\x1a\x1f.rips.ClientToServerStreamReply\"\x00(\x01\x12\x46\n\x13\x43\x61llPdmObjectMethod\x12\x1c.rips.PdmObjectMethodRequest\x1a\x0f.rips.PdmObject\"\x00\x62\x06proto3'
  ,
  dependencies=[Definitions__pb2.DESCRIPTOR,])




_PDMDESCENDANTOBJECTREQUEST = _descriptor.Descriptor(
  name='PdmDescendantObjectRequest',
  full_name='rips.PdmDescendantObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='rips.PdmDescendantObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_keyword', full_name='rips.PdmDescendantObjectRequest.child_keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=128,
)


_PDMCHILDOBJECTREQUEST = _descriptor.Descriptor(
  name='PdmChildObjectRequest',
  full_name='rips.PdmChildObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='rips.PdmChildObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_field', full_name='rips.PdmChildObjectRequest.child_field', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=207,
)


_CREATEPDMCHILDOBJECTREQUEST = _descriptor.Descriptor(
  name='CreatePdmChildObjectRequest',
  full_name='rips.CreatePdmChildObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='rips.CreatePdmChildObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_field', full_name='rips.CreatePdmChildObjectRequest.child_field', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_keyword', full_name='rips.CreatePdmChildObjectRequest.class_keyword', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=315,
)


_PDMPARENTOBJECTREQUEST = _descriptor.Descriptor(
  name='PdmParentObjectRequest',
  full_name='rips.PdmParentObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='rips.PdmParentObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_keyword', full_name='rips.PdmParentObjectRequest.parent_keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=317,
  serialized_end=398,
)


_PDMOBJECT_PARAMETERSENTRY = _descriptor.Descriptor(
  name='ParametersEntry',
  full_name='rips.PdmObject.ParametersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='rips.PdmObject.ParametersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='rips.PdmObject.ParametersEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=544,
  serialized_end=593,
)

_PDMOBJECT = _descriptor.Descriptor(
  name='PdmObject',
  full_name='rips.PdmObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_keyword', full_name='rips.PdmObject.class_keyword', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='rips.PdmObject.address', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='rips.PdmObject.parameters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visible', full_name='rips.PdmObject.visible', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='rips.PdmObject.persistent', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PDMOBJECT_PARAMETERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=593,
)


_PDMOBJECTARRAY = _descriptor.Descriptor(
  name='PdmObjectArray',
  full_name='rips.PdmObjectArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='rips.PdmObjectArray.objects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=645,
)


_PDMOBJECTGETTERREQUEST = _descriptor.Descriptor(
  name='PdmObjectGetterRequest',
  full_name='rips.PdmObjectGetterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='rips.PdmObjectGetterRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='rips.PdmObjectGetterRequest.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=720,
)


_PDMOBJECTSETTERREQUEST = _descriptor.Descriptor(
  name='PdmObjectSetterRequest',
  full_name='rips.PdmObjectSetterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='rips.PdmObjectSetterRequest.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_count', full_name='rips.PdmObjectSetterRequest.data_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=722,
  serialized_end=813,
)


_PDMOBJECTSETTERCHUNK = _descriptor.Descriptor(
  name='PdmObjectSetterChunk',
  full_name='rips.PdmObjectSetterChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='set_request', full_name='rips.PdmObjectSetterChunk.set_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doubles', full_name='rips.PdmObjectSetterChunk.doubles', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ints', full_name='rips.PdmObjectSetterChunk.ints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strings', full_name='rips.PdmObjectSetterChunk.strings', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='rips.PdmObjectSetterChunk.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=816,
  serialized_end=1007,
)


_DOUBLEARRAY = _descriptor.Descriptor(
  name='DoubleArray',
  full_name='rips.DoubleArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rips.DoubleArray.data', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1009,
  serialized_end=1036,
)


_INTARRAY = _descriptor.Descriptor(
  name='IntArray',
  full_name='rips.IntArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rips.IntArray.data', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1038,
  serialized_end=1062,
)


_STRINGARRAY = _descriptor.Descriptor(
  name='StringArray',
  full_name='rips.StringArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rips.StringArray.data', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1064,
  serialized_end=1091,
)


_PDMOBJECTGETTERREPLY = _descriptor.Descriptor(
  name='PdmObjectGetterReply',
  full_name='rips.PdmObjectGetterReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='doubles', full_name='rips.PdmObjectGetterReply.doubles', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ints', full_name='rips.PdmObjectGetterReply.ints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strings', full_name='rips.PdmObjectGetterReply.strings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='rips.PdmObjectGetterReply.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1094,
  serialized_end=1232,
)


_PDMOBJECTMETHODREQUEST = _descriptor.Descriptor(
  name='PdmObjectMethodRequest',
  full_name='rips.PdmObjectMethodRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='rips.PdmObjectMethodRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='rips.PdmObjectMethodRequest.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='rips.PdmObjectMethodRequest.params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1234,
  serialized_end=1340,
)

_PDMDESCENDANTOBJECTREQUEST.fields_by_name['object'].message_type = _PDMOBJECT
_PDMCHILDOBJECTREQUEST.fields_by_name['object'].message_type = _PDMOBJECT
_CREATEPDMCHILDOBJECTREQUEST.fields_by_name['object'].message_type = _PDMOBJECT
_PDMPARENTOBJECTREQUEST.fields_by_name['object'].message_type = _PDMOBJECT
_PDMOBJECT_PARAMETERSENTRY.containing_type = _PDMOBJECT
_PDMOBJECT.fields_by_name['parameters'].message_type = _PDMOBJECT_PARAMETERSENTRY
_PDMOBJECTARRAY.fields_by_name['objects'].message_type = _PDMOBJECT
_PDMOBJECTGETTERREQUEST.fields_by_name['object'].message_type = _PDMOBJECT
_PDMOBJECTSETTERREQUEST.fields_by_name['request'].message_type = _PDMOBJECTGETTERREQUEST
_PDMOBJECTSETTERCHUNK.fields_by_name['set_request'].message_type = _PDMOBJECTSETTERREQUEST
_PDMOBJECTSETTERCHUNK.fields_by_name['doubles'].message_type = _DOUBLEARRAY
_PDMOBJECTSETTERCHUNK.fields_by_name['ints'].message_type = _INTARRAY
_PDMOBJECTSETTERCHUNK.fields_by_name['strings'].message_type = _STRINGARRAY
_PDMOBJECTSETTERCHUNK.oneofs_by_name['data'].fields.append(
  _PDMOBJECTSETTERCHUNK.fields_by_name['set_request'])
_PDMOBJECTSETTERCHUNK.fields_by_name['set_request'].containing_oneof = _PDMOBJECTSETTERCHUNK.oneofs_by_name['data']
_PDMOBJECTSETTERCHUNK.oneofs_by_name['data'].fields.append(
  _PDMOBJECTSETTERCHUNK.fields_by_name['doubles'])
_PDMOBJECTSETTERCHUNK.fields_by_name['doubles'].containing_oneof = _PDMOBJECTSETTERCHUNK.oneofs_by_name['data']
_PDMOBJECTSETTERCHUNK.oneofs_by_name['data'].fields.append(
  _PDMOBJECTSETTERCHUNK.fields_by_name['ints'])
_PDMOBJECTSETTERCHUNK.fields_by_name['ints'].containing_oneof = _PDMOBJECTSETTERCHUNK.oneofs_by_name['data']
_PDMOBJECTSETTERCHUNK.oneofs_by_name['data'].fields.append(
  _PDMOBJECTSETTERCHUNK.fields_by_name['strings'])
_PDMOBJECTSETTERCHUNK.fields_by_name['strings'].containing_oneof = _PDMOBJECTSETTERCHUNK.oneofs_by_name['data']
_PDMOBJECTGETTERREPLY.fields_by_name['doubles'].message_type = _DOUBLEARRAY
_PDMOBJECTGETTERREPLY.fields_by_name['ints'].message_type = _INTARRAY
_PDMOBJECTGETTERREPLY.fields_by_name['strings'].message_type = _STRINGARRAY
_PDMOBJECTGETTERREPLY.oneofs_by_name['data'].fields.append(
  _PDMOBJECTGETTERREPLY.fields_by_name['doubles'])
_PDMOBJECTGETTERREPLY.fields_by_name['doubles'].containing_oneof = _PDMOBJECTGETTERREPLY.oneofs_by_name['data']
_PDMOBJECTGETTERREPLY.oneofs_by_name['data'].fields.append(
  _PDMOBJECTGETTERREPLY.fields_by_name['ints'])
_PDMOBJECTGETTERREPLY.fields_by_name['ints'].containing_oneof = _PDMOBJECTGETTERREPLY.oneofs_by_name['data']
_PDMOBJECTGETTERREPLY.oneofs_by_name['data'].fields.append(
  _PDMOBJECTGETTERREPLY.fields_by_name['strings'])
_PDMOBJECTGETTERREPLY.fields_by_name['strings'].containing_oneof = _PDMOBJECTGETTERREPLY.oneofs_by_name['data']
_PDMOBJECTMETHODREQUEST.fields_by_name['object'].message_type = _PDMOBJECT
_PDMOBJECTMETHODREQUEST.fields_by_name['params'].message_type = _PDMOBJECT
DESCRIPTOR.message_types_by_name['PdmDescendantObjectRequest'] = _PDMDESCENDANTOBJECTREQUEST
DESCRIPTOR.message_types_by_name['PdmChildObjectRequest'] = _PDMCHILDOBJECTREQUEST
DESCRIPTOR.message_types_by_name['CreatePdmChildObjectRequest'] = _CREATEPDMCHILDOBJECTREQUEST
DESCRIPTOR.message_types_by_name['PdmParentObjectRequest'] = _PDMPARENTOBJECTREQUEST
DESCRIPTOR.message_types_by_name['PdmObject'] = _PDMOBJECT
DESCRIPTOR.message_types_by_name['PdmObjectArray'] = _PDMOBJECTARRAY
DESCRIPTOR.message_types_by_name['PdmObjectGetterRequest'] = _PDMOBJECTGETTERREQUEST
DESCRIPTOR.message_types_by_name['PdmObjectSetterRequest'] = _PDMOBJECTSETTERREQUEST
DESCRIPTOR.message_types_by_name['PdmObjectSetterChunk'] = _PDMOBJECTSETTERCHUNK
DESCRIPTOR.message_types_by_name['DoubleArray'] = _DOUBLEARRAY
DESCRIPTOR.message_types_by_name['IntArray'] = _INTARRAY
DESCRIPTOR.message_types_by_name['StringArray'] = _STRINGARRAY
DESCRIPTOR.message_types_by_name['PdmObjectGetterReply'] = _PDMOBJECTGETTERREPLY
DESCRIPTOR.message_types_by_name['PdmObjectMethodRequest'] = _PDMOBJECTMETHODREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PdmDescendantObjectRequest = _reflection.GeneratedProtocolMessageType('PdmDescendantObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _PDMDESCENDANTOBJECTREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmDescendantObjectRequest)
  })
_sym_db.RegisterMessage(PdmDescendantObjectRequest)

PdmChildObjectRequest = _reflection.GeneratedProtocolMessageType('PdmChildObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _PDMCHILDOBJECTREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmChildObjectRequest)
  })
_sym_db.RegisterMessage(PdmChildObjectRequest)

CreatePdmChildObjectRequest = _reflection.GeneratedProtocolMessageType('CreatePdmChildObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPDMCHILDOBJECTREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.CreatePdmChildObjectRequest)
  })
_sym_db.RegisterMessage(CreatePdmChildObjectRequest)

PdmParentObjectRequest = _reflection.GeneratedProtocolMessageType('PdmParentObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _PDMPARENTOBJECTREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmParentObjectRequest)
  })
_sym_db.RegisterMessage(PdmParentObjectRequest)

PdmObject = _reflection.GeneratedProtocolMessageType('PdmObject', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _PDMOBJECT_PARAMETERSENTRY,
    '__module__' : 'PdmObject_pb2'
    # @@protoc_insertion_point(class_scope:rips.PdmObject.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _PDMOBJECT,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObject)
  })
_sym_db.RegisterMessage(PdmObject)
_sym_db.RegisterMessage(PdmObject.ParametersEntry)

PdmObjectArray = _reflection.GeneratedProtocolMessageType('PdmObjectArray', (_message.Message,), {
  'DESCRIPTOR' : _PDMOBJECTARRAY,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObjectArray)
  })
_sym_db.RegisterMessage(PdmObjectArray)

PdmObjectGetterRequest = _reflection.GeneratedProtocolMessageType('PdmObjectGetterRequest', (_message.Message,), {
  'DESCRIPTOR' : _PDMOBJECTGETTERREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObjectGetterRequest)
  })
_sym_db.RegisterMessage(PdmObjectGetterRequest)

PdmObjectSetterRequest = _reflection.GeneratedProtocolMessageType('PdmObjectSetterRequest', (_message.Message,), {
  'DESCRIPTOR' : _PDMOBJECTSETTERREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObjectSetterRequest)
  })
_sym_db.RegisterMessage(PdmObjectSetterRequest)

PdmObjectSetterChunk = _reflection.GeneratedProtocolMessageType('PdmObjectSetterChunk', (_message.Message,), {
  'DESCRIPTOR' : _PDMOBJECTSETTERCHUNK,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObjectSetterChunk)
  })
_sym_db.RegisterMessage(PdmObjectSetterChunk)

DoubleArray = _reflection.GeneratedProtocolMessageType('DoubleArray', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEARRAY,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.DoubleArray)
  })
_sym_db.RegisterMessage(DoubleArray)

IntArray = _reflection.GeneratedProtocolMessageType('IntArray', (_message.Message,), {
  'DESCRIPTOR' : _INTARRAY,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.IntArray)
  })
_sym_db.RegisterMessage(IntArray)

StringArray = _reflection.GeneratedProtocolMessageType('StringArray', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAY,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.StringArray)
  })
_sym_db.RegisterMessage(StringArray)

PdmObjectGetterReply = _reflection.GeneratedProtocolMessageType('PdmObjectGetterReply', (_message.Message,), {
  'DESCRIPTOR' : _PDMOBJECTGETTERREPLY,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObjectGetterReply)
  })
_sym_db.RegisterMessage(PdmObjectGetterReply)

PdmObjectMethodRequest = _reflection.GeneratedProtocolMessageType('PdmObjectMethodRequest', (_message.Message,), {
  'DESCRIPTOR' : _PDMOBJECTMETHODREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObjectMethodRequest)
  })
_sym_db.RegisterMessage(PdmObjectMethodRequest)


_PDMOBJECT_PARAMETERSENTRY._options = None

_PDMOBJECTSERVICE = _descriptor.ServiceDescriptor(
  name='PdmObjectService',
  full_name='rips.PdmObjectService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1343,
  serialized_end=1976,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetDescendantPdmObjects',
    full_name='rips.PdmObjectService.GetDescendantPdmObjects',
    index=0,
    containing_service=None,
    input_type=_PDMDESCENDANTOBJECTREQUEST,
    output_type=_PDMOBJECTARRAY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChildPdmObjects',
    full_name='rips.PdmObjectService.GetChildPdmObjects',
    index=1,
    containing_service=None,
    input_type=_PDMCHILDOBJECTREQUEST,
    output_type=_PDMOBJECTARRAY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAncestorPdmObject',
    full_name='rips.PdmObjectService.GetAncestorPdmObject',
    index=2,
    containing_service=None,
    input_type=_PDMPARENTOBJECTREQUEST,
    output_type=_PDMOBJECT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateChildPdmObject',
    full_name='rips.PdmObjectService.CreateChildPdmObject',
    index=3,
    containing_service=None,
    input_type=_CREATEPDMCHILDOBJECTREQUEST,
    output_type=_PDMOBJECT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateExistingPdmObject',
    full_name='rips.PdmObjectService.UpdateExistingPdmObject',
    index=4,
    containing_service=None,
    input_type=_PDMOBJECT,
    output_type=Definitions__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CallPdmObjectGetter',
    full_name='rips.PdmObjectService.CallPdmObjectGetter',
    index=5,
    containing_service=None,
    input_type=_PDMOBJECTGETTERREQUEST,
    output_type=_PDMOBJECTGETTERREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CallPdmObjectSetter',
    full_name='rips.PdmObjectService.CallPdmObjectSetter',
    index=6,
    containing_service=None,
    input_type=_PDMOBJECTSETTERCHUNK,
    output_type=Definitions__pb2._CLIENTTOSERVERSTREAMREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CallPdmObjectMethod',
    full_name='rips.PdmObjectService.CallPdmObjectMethod',
    index=7,
    containing_service=None,
    input_type=_PDMOBJECTMETHODREQUEST,
    output_type=_PDMOBJECT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PDMOBJECTSERVICE)

DESCRIPTOR.services_by_name['PdmObjectService'] = _PDMOBJECTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: NNCProperties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Case_pb2 as Case__pb2
import Definitions_pb2 as Definitions__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='NNCProperties.proto',
  package='rips',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13NNCProperties.proto\x12\x04rips\x1a\nCase.proto\x1a\x11\x44\x65\x66initions.proto\"R\n\x14\x41vailableNNCProperty\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\rproperty_type\x18\x02 \x01(\x0e\x32\x15.rips.NNCPropertyType\"H\n\x16\x41vailableNNCProperties\x12.\n\nproperties\x18\x01 \x03(\x0b\x32\x1a.rips.AvailableNNCProperty\"{\n\rNNCConnection\x12\x18\n\x10\x63\x65ll_grid_index1\x18\x01 \x01(\x05\x12\x18\n\x10\x63\x65ll_grid_index2\x18\x02 \x01(\x05\x12\x1a\n\x05\x63\x65ll1\x18\x03 \x01(\x0b\x32\x0b.rips.Vec3i\x12\x1a\n\x05\x63\x65ll2\x18\x04 \x01(\x0b\x32\x0b.rips.Vec3i\":\n\x0eNNCConnections\x12(\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32\x13.rips.NNCConnection\"{\n\x10NNCValuesRequest\x12\x0f\n\x07\x63\x61se_id\x18\x01 \x01(\x05\x12\x15\n\rproperty_name\x18\x02 \x01(\t\x12,\n\rproperty_type\x18\x03 \x01(\x0e\x32\x15.rips.NNCPropertyType\x12\x11\n\ttime_step\x18\x04 \x01(\x05\"\x1b\n\tNNCValues\x12\x0e\n\x06values\x18\x01 \x03(\x01\"\x83\x01\n\x15NNCValuesInputRequest\x12\x0f\n\x07\x63\x61se_id\x18\x01 \x01(\x05\x12\x15\n\rproperty_name\x18\x02 \x01(\t\x12/\n\x0eporosity_model\x18\x03 \x01(\x0e\x32\x17.rips.PorosityModelType\x12\x11\n\ttime_step\x18\x04 \x01(\x05\"o\n\x0eNNCValuesChunk\x12-\n\x06params\x18\x01 \x01(\x0b\x32\x1b.rips.NNCValuesInputRequestH\x00\x12!\n\x06values\x18\x02 \x01(\x0b\x32\x0f.rips.NNCValuesH\x00\x42\x0b\n\tChunkType*E\n\x0fNNCPropertyType\x12\x0f\n\x0bNNC_DYNAMIC\x10\x00\x12\x0e\n\nNNC_STATIC\x10\x01\x12\x11\n\rNNC_GENERATED\x10\x02\x32\xa9\x02\n\rNNCProperties\x12N\n\x19GetAvailableNNCProperties\x12\x11.rips.CaseRequest\x1a\x1c.rips.AvailableNNCProperties\"\x00\x12@\n\x11GetNNCConnections\x12\x11.rips.CaseRequest\x1a\x14.rips.NNCConnections\"\x00\x30\x01\x12;\n\x0cGetNNCValues\x12\x16.rips.NNCValuesRequest\x1a\x0f.rips.NNCValues\"\x00\x30\x01\x12I\n\x0cSetNNCValues\x12\x14.rips.NNCValuesChunk\x1a\x1f.rips.ClientToServerStreamReply\"\x00(\x01\x62\x06proto3'
  ,
  dependencies=[Case__pb2.DESCRIPTOR,Definitions__pb2.DESCRIPTOR,])

_NNCPROPERTYTYPE = _descriptor.EnumDescriptor(
  name='NNCPropertyType',
  full_name='rips.NNCPropertyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NNC_DYNAMIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NNC_STATIC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NNC_GENERATED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=804,
  serialized_end=873,
)
_sym_db.RegisterEnumDescriptor(_NNCPROPERTYTYPE)

NNCPropertyType = enum_type_wrapper.EnumTypeWrapper(_NNCPROPERTYTYPE)
NNC_DYNAMIC = 0
NNC_STATIC = 1
NNC_GENERATED = 2



_AVAILABLENNCPROPERTY = _descriptor.Descriptor(
  name='AvailableNNCProperty',
  full_name='rips.AvailableNNCProperty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rips.AvailableNNCProperty.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_type', full_name='rips.AvailableNNCProperty.property_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=142,
)


_AVAILABLENNCPROPERTIES = _descriptor.Descriptor(
  name='AvailableNNCProperties',
  full_name='rips.AvailableNNCProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='properties', full_name='rips.AvailableNNCProperties.properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=216,
)


_NNCCONNECTION = _descriptor.Descriptor(
  name='NNCConnection',
  full_name='rips.NNCConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_grid_index1', full_name='rips.NNCConnection.cell_grid_index1', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_grid_index2', full_name='rips.NNCConnection.cell_grid_index2', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell1', full_name='rips.NNCConnection.cell1', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell2', full_name='rips.NNCConnection.cell2', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=341,
)


_NNCCONNECTIONS = _descriptor.Descriptor(
  name='NNCConnections',
  full_name='rips.NNCConnections',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connections', full_name='rips.NNCConnections.connections', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=401,
)


_NNCVALUESREQUEST = _descriptor.Descriptor(
  name='NNCValuesRequest',
  full_name='rips.NNCValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='case_id', full_name='rips.NNCValuesRequest.case_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_name', full_name='rips.NNCValuesRequest.property_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_type', full_name='rips.NNCValuesRequest.property_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_step', full_name='rips.NNCValuesRequest.time_step', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=526,
)


_NNCVALUES = _descriptor.Descriptor(
  name='NNCValues',
  full_name='rips.NNCValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='rips.NNCValues.values', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=555,
)


_NNCVALUESINPUTREQUEST = _descriptor.Descriptor(
  name='NNCValuesInputRequest',
  full_name='rips.NNCValuesInputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='case_id', full_name='rips.NNCValuesInputRequest.case_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_name', full_name='rips.NNCValuesInputRequest.property_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='porosity_model', full_name='rips.NNCValuesInputRequest.porosity_model', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_step', full_name='rips.NNCValuesInputRequest.time_step', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=558,
  serialized_end=689,
)


_NNCVALUESCHUNK = _descriptor.Descriptor(
  name='NNCValuesChunk',
  full_name='rips.NNCValuesChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='rips.NNCValuesChunk.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='rips.NNCValuesChunk.values', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ChunkType', full_name='rips.NNCValuesChunk.ChunkType',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=691,
  serialized_end=802,
)

_AVAILABLENNCPROPERTY.fields_by_name['property_type'].enum_type = _NNCPROPERTYTYPE
_AVAILABLENNCPROPERTIES.fields_by_name['properties'].message_type = _AVAILABLENNCPROPERTY
_NNCCONNECTION.fields_by_name['cell1'].message_type = Definitions__pb2._VEC3I
_NNCCONNECTION.fields_by_name['cell2'].message_type = Definitions__pb2._VEC3I
_NNCCONNECTIONS.fields_by_name['connections'].message_type = _NNCCONNECTION
_NNCVALUESREQUEST.fields_by_name['property_type'].enum_type = _NNCPROPERTYTYPE
_NNCVALUESINPUTREQUEST.fields_by_name['porosity_model'].enum_type = Case__pb2._POROSITYMODELTYPE
_NNCVALUESCHUNK.fields_by_name['params'].message_type = _NNCVALUESINPUTREQUEST
_NNCVALUESCHUNK.fields_by_name['values'].message_type = _NNCVALUES
_NNCVALUESCHUNK.oneofs_by_name['ChunkType'].fields.append(
  _NNCVALUESCHUNK.fields_by_name['params'])
_NNCVALUESCHUNK.fields_by_name['params'].containing_oneof = _NNCVALUESCHUNK.oneofs_by_name['ChunkType']
_NNCVALUESCHUNK.oneofs_by_name['ChunkType'].fields.append(
  _NNCVALUESCHUNK.fields_by_name['values'])
_NNCVALUESCHUNK.fields_by_name['values'].containing_oneof = _NNCVALUESCHUNK.oneofs_by_name['ChunkType']
DESCRIPTOR.message_types_by_name['AvailableNNCProperty'] = _AVAILABLENNCPROPERTY
DESCRIPTOR.message_types_by_name['AvailableNNCProperties'] = _AVAILABLENNCPROPERTIES
DESCRIPTOR.message_types_by_name['NNCConnection'] = _NNCCONNECTION
DESCRIPTOR.message_types_by_name['NNCConnections'] = _NNCCONNECTIONS
DESCRIPTOR.message_types_by_name['NNCValuesRequest'] = _NNCVALUESREQUEST
DESCRIPTOR.message_types_by_name['NNCValues'] = _NNCVALUES
DESCRIPTOR.message_types_by_name['NNCValuesInputRequest'] = _NNCVALUESINPUTREQUEST
DESCRIPTOR.message_types_by_name['NNCValuesChunk'] = _NNCVALUESCHUNK
DESCRIPTOR.enum_types_by_name['NNCPropertyType'] = _NNCPROPERTYTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AvailableNNCProperty = _reflection.GeneratedProtocolMessageType('AvailableNNCProperty', (_message.Message,), {
  'DESCRIPTOR' : _AVAILABLENNCPROPERTY,
  '__module__' : 'NNCProperties_pb2'
  # @@protoc_insertion_point(class_scope:rips.AvailableNNCProperty)
  })
_sym_db.RegisterMessage(AvailableNNCProperty)

AvailableNNCProperties = _reflection.GeneratedProtocolMessageType('AvailableNNCProperties', (_message.Message,), {
  'DESCRIPTOR' : _AVAILABLENNCPROPERTIES,
  '__module__' : 'NNCProperties_pb2'
  # @@protoc_insertion_point(class_scope:rips.AvailableNNCProperties)
  })
_sym_db.RegisterMessage(AvailableNNCProperties)

NNCConnection = _reflection.GeneratedProtocolMessageType('NNCConnection', (_message.Message,), {
  'DESCRIPTOR' : _NNCCONNECTION,
  '__module__' : 'NNCProperties_pb2'
  # @@protoc_insertion_point(class_scope:rips.NNCConnection)
  })
_sym_db.RegisterMessage(NNCConnection)

NNCConnections = _reflection.GeneratedProtocolMessageType('NNCConnections', (_message.Message,), {
  'DESCRIPTOR' : _NNCCONNECTIONS,
  '__module__' : 'NNCProperties_pb2'
  # @@protoc_insertion_point(class_scope:rips.NNCConnections)
  })
_sym_db.RegisterMessage(NNCConnections)

NNCValuesRequest = _reflection.GeneratedProtocolMessageType('NNCValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _NNCVALUESREQUEST,
  '__module__' : 'NNCProperties_pb2'
  # @@protoc_insertion_point(class_scope:rips.NNCValuesRequest)
  })
_sym_db.RegisterMessage(NNCValuesRequest)

NNCValues = _reflection.GeneratedProtocolMessageType('NNCValues', (_message.Message,), {
  'DESCRIPTOR' : _NNCVALUES,
  '__module__' : 'NNCProperties_pb2'
  # @@protoc_insertion_point(class_scope:rips.NNCValues)
  })
_sym_db.RegisterMessage(NNCValues)

NNCValuesInputRequest = _reflection.GeneratedProtocolMessageType('NNCValuesInputRequest', (_message.Message,), {
  'DESCRIPTOR' : _NNCVALUESINPUTREQUEST,
  '__module__' : 'NNCProperties_pb2'
  # @@protoc_insertion_point(class_scope:rips.NNCValuesInputRequest)
  })
_sym_db.RegisterMessage(NNCValuesInputRequest)

NNCValuesChunk = _reflection.GeneratedProtocolMessageType('NNCValuesChunk', (_message.Message,), {
  'DESCRIPTOR' : _NNCVALUESCHUNK,
  '__module__' : 'NNCProperties_pb2'
  # @@protoc_insertion_point(class_scope:rips.NNCValuesChunk)
  })
_sym_db.RegisterMessage(NNCValuesChunk)



_NNCPROPERTIES = _descriptor.ServiceDescriptor(
  name='NNCProperties',
  full_name='rips.NNCProperties',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=876,
  serialized_end=1173,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAvailableNNCProperties',
    full_name='rips.NNCProperties.GetAvailableNNCProperties',
    index=0,
    containing_service=None,
    input_type=Case__pb2._CASEREQUEST,
    output_type=_AVAILABLENNCPROPERTIES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNNCConnections',
    full_name='rips.NNCProperties.GetNNCConnections',
    index=1,
    containing_service=None,
    input_type=Case__pb2._CASEREQUEST,
    output_type=_NNCCONNECTIONS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNNCValues',
    full_name='rips.NNCProperties.GetNNCValues',
    index=2,
    containing_service=None,
    input_type=_NNCVALUESREQUEST,
    output_type=_NNCVALUES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetNNCValues',
    full_name='rips.NNCProperties.SetNNCValues',
    index=3,
    containing_service=None,
    input_type=_NNCVALUESCHUNK,
    output_type=Definitions__pb2._CLIENTTOSERVERSTREAMREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NNCPROPERTIES)

DESCRIPTOR.services_by_name['NNCProperties'] = _NNCPROPERTIES

# @@protoc_insertion_point(module_scope)
